@@ -9,10 +9,10 @@
 NAME = 'python-facebook-api'
 DESCRIPTION = 'A Python wrapper around the Facebook API'
 LICENCE = 'Apache License 2.0'
-URL = 'https://github.com/MerleLiuKun/python-facebook'
+URL = 'https://github.com/sns-sdks/python-facebook'
 EMAIL = 'merle.liukun@gmail.com'
 AUTHOR = 'Ikaros kun'
 REQUIRES_PYTHON = '>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*, !=3.4.*'
-VERSION = (0, 5, 5)
+VERSION = (0, 6, 0)
 
 __version__ = '.'.join(map(str, VERSION))
